@@ -1,5 +1,4 @@
 import csv
-import os.path
 import pathlib
 import sys
 from collections import defaultdict
@@ -64,7 +63,7 @@ class Command(BaseCommand):
                     recurse(value)
 
         with open(self.args.file) as f:
-            schema = jsonref.load(f, base_uri=pathlib.Path(os.path.realpath(self.args.file)).as_uri())
+            schema = jsonref.load(f, base_uri=pathlib.Path(self.args.file).resolve().as_uri())
 
         codelists = defaultdict(set)
         definitions = defaultdict(int)
