@@ -3,6 +3,7 @@ import re
 
 from ocdskit.exceptions import MissingColumnError
 from ocdskit.schema import get_schema_fields
+from ocdskit.util import _cast_as_list
 
 # See https://stackoverflow.com/questions/30734682/extracting-url-and-anchor-text-from-markdown-using-python
 INLINE_LINK_RE = re.compile(r'\[([^\]]+)\]\(([^)]+)\)')
@@ -76,12 +77,17 @@ def mapping_sheet(schema, io, order_by=None, infer_required=False, extension_fie
 
         # If the field is an array, add an extra row for it. This makes it easier to use as a header for the object.
         if 'items' in prop and 'properties' in prop['items'] and 'title' in prop['items']:
-            _add_row(rows, rows_by_path, field, prop['items'], extension_field, row={
+            row = {
                 'path': field.path,
                 'title': prop['items']['title'],
                 'description': prop['items'].get('description', ''),
                 'type': prop['items']['type'],
-            }, include_deprecated=include_deprecated)
+                'deprecated': field.deprecated.get('deprecatedVersion'),  # deprecation from parent
+            }
+            _add_deprecated(row, prop['items'])
+
+            _add_row(rows, rows_by_path, field, prop['items'], extension_field, row=row,
+                     include_deprecated=include_deprecated)
 
     if order_by:
         try:
@@ -99,6 +105,12 @@ def mapping_sheet(schema, io, order_by=None, infer_required=False, extension_fie
     writer.writerows(rows)
 
 
+def _add_deprecated(row, schema):
+    if 'deprecated' in schema:
+        row['deprecated'] = schema['deprecated'].get('deprecatedVersion', '')
+        row['deprecationNotes'] = schema['deprecated'].get('description', '')
+
+
 def _add_row(rows, rows_by_path, field, schema, extension_field, *, infer_required=None, include_deprecated=True,
              row=None):
     parent = rows_by_path.get(field.path_components[:-1], {})
@@ -138,17 +150,14 @@ def _make_row(field, schema, infer_required):
     required = False
 
     if 'type' in schema:
-        if isinstance(schema['type'], str):
-            type_ = [schema['type']]
-        else:
-            type_ = list(schema['type'])
+        types = _cast_as_list(schema['type'])
 
-        if 'null' in type_:
-            type_.remove('null')
+        if 'null' in types:
+            types.remove('null')
         elif infer_required:
-            required = 'string' in type_ or 'integer' in type_
+            required = 'string' in types or 'integer' in types
 
-        row['type'] = ', '.join(type_)
+        row['type'] = ', '.join(types)
     else:
         row['type'] = 'unknown'
 
@@ -176,8 +185,6 @@ def _make_row(field, schema, infer_required):
     else:
         row['values'] = ''
 
-    if 'deprecated' in schema:
-        row['deprecated'] = schema['deprecated'].get('deprecatedVersion', '')
-        row['deprecationNotes'] = schema['deprecated'].get('description', '')
+    _add_deprecated(row, schema)
 
     return row
