@@ -1,6 +1,7 @@
 import itertools
 import json
 from decimal import Decimal
+
 import ijson
 
 from ocdskit.exceptions import UnknownFormatError
@@ -301,3 +302,9 @@ def _remove_empty_optional_metadata(output):
     for field in ('license', 'publicationPolicy', 'version'):
         if output[field] is None:
             del output[field]
+
+
+def _cast_as_list(value):
+    if isinstance(value, str):
+        return [value]
+    return sorted(value)
