@@ -3,10 +3,7 @@ import sys
 from io import BytesIO, StringIO, TextIOWrapper
 from unittest.mock import patch
 
-import pytest
-
 from ocdskit.cli.__main__ import main
-from ocdskit.exceptions import MissingRecordsWarning
 from tests import assert_streaming, read, run_streaming
 
 
@@ -24,12 +21,13 @@ def test_command_no_extensions(monkeypatch):
 
 def test_command_uri_published_date(monkeypatch):
     actual = run_streaming(monkeypatch, main, ['combine-record-packages', '--uri', 'http://example.com/x.json',
-                                               '--published-date', '2010-01-01T00:00:00Z'],
+                                               '--published-date', '2010-01-01T00:00:00Z', '--version', '1.2'],
                            ['record-package_minimal.json'])
 
     package = json.loads(actual)
     assert package['uri'] == 'http://example.com/x.json'
     assert package['publishedDate'] == '2010-01-01T00:00:00Z'
+    assert package['version'] == '1.2'
 
 
 def test_command_publisher(monkeypatch):
@@ -49,7 +47,7 @@ def test_command_missing_field(stdout, stderr, monkeypatch):
         monkeypatch.setattr(sys, 'argv', ['ocdskit', 'combine-record-packages'])
         main()
 
-    assert stdout.getvalue() == '{"uri":"","publisher":{"name":"Acme"},"publishedDate":"","version":"1.1","records":[]}\n'
+    assert stdout.getvalue() == '{"uri":"","publisher":{"name":"Acme"},"publishedDate":"","version":"1.1","records":[]}\n'  # noqa: E501
     assert stderr.getvalue() == 'item 0 has no "records" field (check that it is a record package)\n'
 
 
